
from shut.commands import shut


if __name__ == '__main__':
  shut()  #: pylint: disable=all
